@@ -8,8 +8,8 @@ test_that("`ver_dict` is updated and correct", {
                  "SL-12345678-rev0-2021-01",
                  "SL-00000571-rev2-2021-06",
                  "SL-00000246-rev5-2021-06",
-                 "SL-906-rev3-2024-02",
-                 "SL-00000571-rev7-2024-02"))
+                 "SL-00000571-rev7-2024-02",
+                 "SL-00000906-rev4-2024-03"))
 })
 
 test_that("`getAnnoVer()` parses the version correctly", {
@@ -25,3 +25,24 @@ test_that("`read_annotations()` parses the annotations file correctly", {
   expect_true(ver_dict[[ver]]$col_serum == names(tbl)[ver_dict[[ver]]$which_serum])
   expect_true(ver_dict[[ver]]$col_plasma == names(tbl)[ver_dict[[ver]]$which_plasma])
 })
+
+test_that("error conditions trigger stops when appropriate", {
+
+  expect_error(
+    read_annotations("foo.txt"),
+    "Annotations file must be either"
+  )
+
+  expect_error(
+    with_pkg_object(SomaDataIO:::ver_dict[-2L], read_annotations(file)),
+    "Unknown version of the annotations file:"
+  )
+
+  # temp modify md5sha
+  tmp <- SomaDataIO:::ver_dict
+  tmp$`SL-12345678-rev0-2021-01`$sha <- "x0x0x0x0x"
+  expect_warning(
+    with_pkg_object(tmp, read_annotations(file)),
+    "Checksum mismatch. 'test-anno.xlsx' may have been modified"
+  )
+})
